<?php

return [
    // Properties changed from public to protected
    'TYPO3\CMS\Core\DataHandling\DataHandler->recUpdateAccessCache' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79441-ChangeVisibilityInternalCacheDatahandler.rst',
        ],
    ],
    'TYPO3\CMS\Core\DataHandling\DataHandler->recInsertAccessCache' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79441-ChangeVisibilityInternalCacheDatahandler.rst',
        ],
    ],
    'TYPO3\CMS\Core\DataHandling\DataHandler->isRecordInWebMount_Cache' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79441-ChangeVisibilityInternalCacheDatahandler.rst',
        ],
    ],
    'TYPO3\CMS\Core\DataHandling\DataHandler->isInWebMount_Cache' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79441-ChangeVisibilityInternalCacheDatahandler.rst',
        ],
    ],
    'TYPO3\CMS\Core\DataHandling\DataHandler->cachedTSconfig' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79441-ChangeVisibilityInternalCacheDatahandler.rst',
        ],
    ],
    'TYPO3\CMS\Core\DataHandling\DataHandler->pageCache' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79441-ChangeVisibilityInternalCacheDatahandler.rst',
        ],
    ],
    'TYPO3\CMS\Backend\History\RecordHistory->maxSteps' => [
        'restFiles' => [
            'Breaking-55298-DecoupledHistoryFunctionality.rst',
        ],
    ],
    'TYPO3\CMS\Backend\History\RecordHistory->showSubElements' => [
        'restFiles' => [
            'Breaking-55298-DecoupledHistoryFunctionality.rst',
        ],
    ],
    'TYPO3\CMS\Backend\History\RecordHistory->element' => [
        'restFiles' => [
            'Breaking-55298-DecoupledHistoryFunctionality.rst',
        ],
    ],
    'TYPO3\CMS\Core\Core\Bootstrap->installToolPath' => [
        'restFiles' => [
            'Important-83869-RemovedRequestTypeSpecificCodeInBootstrap.rst',
        ],
    ],
    'TYPO3\CMS\Core\Core\Bootstrap->availableRequestHandlers' => [
        'restFiles' => [
            'Important-83869-RemovedRequestTypeSpecificCodeInBootstrap.rst',
        ],
    ],
    'TYPO3\CMS\Core\Core\Bootstrap->response' => [
        'restFiles' => [
            'Important-83869-RemovedRequestTypeSpecificCodeInBootstrap.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->editconf' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->defVals' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->overrideVals' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->columnsOnly' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->returnUrl' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->closeDoc' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->doSave' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->returnEditConf' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->retUrl' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->R_URL_parts' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->R_URL_getvars' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->storeArray' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->storeUrl' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->storeUrlMd5' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->docDat' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->docHandler' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->cacheCmd' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->redirect' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->returnNewPageId' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->popViewId' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->popViewId_addParams' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->viewUrl' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->recTitle' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->noView' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->MCONF' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->perms_clause' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->content' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->R_URI' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->pageinfo' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->storeTitle' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->firstEl' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->errorC' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->newC' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->viewId' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->viewId_addParams' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->modTSconfig' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->dontStoreDocumentRef' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\EditDocumentController->elementsData' => [
        'restFiles' => [
            'Deprecation-84195-ProtectedMethodsAndPropertiesInEditDocumentController.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\FileSystemNavigationFrameController->foldertree' => [
        'restFiles' => [
            'Deprecation-84273-ProtectedMethodsAndPropertiesInFileSystemNavigationFrameController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\FileSystemNavigationFrameController->currentSubScript' => [
        'restFiles' => [
            'Deprecation-84273-ProtectedMethodsAndPropertiesInFileSystemNavigationFrameController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\FileSystemNavigationFrameController->cMR' => [
        'restFiles' => [
            'Deprecation-84273-ProtectedMethodsAndPropertiesInFileSystemNavigationFrameController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\MoveElementController->sys_language' => [
        'restFiles' => [
            'Deprecation-84285-ProtectedMethodsAndPropertiesInMoveElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\MoveElementController->page_id' => [
        'restFiles' => [
            'Deprecation-84285-ProtectedMethodsAndPropertiesInMoveElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\MoveElementController->R_URI' => [
        'restFiles' => [
            'Deprecation-84285-ProtectedMethodsAndPropertiesInMoveElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\MoveElementController->input_moveUid' => [
        'restFiles' => [
            'Deprecation-84285-ProtectedMethodsAndPropertiesInMoveElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\MoveElementController->moveUid' => [
        'restFiles' => [
            'Deprecation-84285-ProtectedMethodsAndPropertiesInMoveElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\MoveElementController->perms_clause' => [
        'restFiles' => [
            'Deprecation-84285-ProtectedMethodsAndPropertiesInMoveElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\MoveElementController->makeCopy' => [
        'restFiles' => [
            'Deprecation-84285-ProtectedMethodsAndPropertiesInMoveElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\ElementInformationController->access' => [
        'restFiles' => [
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-84284-ProtectedMethodsAndPropertiesInContentElementElementInformationController.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\ElementInformationController->pageInfo' => [
        'restFiles' => [
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-84284-ProtectedMethodsAndPropertiesInContentElementElementInformationController.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\NewContentElementController->sys_language' => [
        'restFiles' => [
            'Deprecation-84307-ProtectedMethodsAndPropertiesInNewContentElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\NewContentElementController->R_URI' => [
        'restFiles' => [
            'Deprecation-84307-ProtectedMethodsAndPropertiesInNewContentElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\NewContentElementController->colPos' => [
        'restFiles' => [
            'Deprecation-84307-ProtectedMethodsAndPropertiesInNewContentElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\NewContentElementController->uid_pid' => [
        'restFiles' => [
            'Deprecation-84307-ProtectedMethodsAndPropertiesInNewContentElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\ContentElement\NewContentElementController->access' => [
        'restFiles' => [
            'Deprecation-84307-ProtectedMethodsAndPropertiesInNewContentElementController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\FileUploadController->title' => [
        'restFiles' => [
            'Deprecation-84326-ProtectedMethodsAndPropertiesInFileUploadController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\FileUploadController->target' => [
        'restFiles' => [
            'Deprecation-84326-ProtectedMethodsAndPropertiesInFileUploadController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\FileUploadController->returnUrl' => [
        'restFiles' => [
            'Deprecation-84326-ProtectedMethodsAndPropertiesInFileUploadController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\ReplaceFileController->doc' => [
        'restFiles' => [
            'Deprecation-84334-ProtectedMethodsAndPropertiesInReplaceFileController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\ReplaceFileController->title' => [
        'restFiles' => [
            'Deprecation-84334-ProtectedMethodsAndPropertiesInReplaceFileController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\ReplaceFileController->uid' => [
        'restFiles' => [
            'Deprecation-84334-ProtectedMethodsAndPropertiesInReplaceFileController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\ReplaceFileController->returnUrl' => [
        'restFiles' => [
            'Deprecation-84334-ProtectedMethodsAndPropertiesInReplaceFileController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\AddController->processDataFlag' => [
        'restFiles' => [
            'Deprecation-84321-ProtectedMethodsAndPropertiesInAddController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\AddController->P' => [
        'restFiles' => [
            'Deprecation-84321-ProtectedMethodsAndPropertiesInAddController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\AddController->returnEditConf' => [
        'restFiles' => [
            'Deprecation-84321-ProtectedMethodsAndPropertiesInAddController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\RenameFileController->title' => [
        'restFiles' => [
            'Deprecation-84332-ProtectedMethodsAndPropertiesInRenameFileController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\RenameFileController->target' => [
        'restFiles' => [
            'Deprecation-84332-ProtectedMethodsAndPropertiesInRenameFileController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\RenameFileController->returnUrl' => [
        'restFiles' => [
            'Deprecation-84332-ProtectedMethodsAndPropertiesInRenameFileController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->pidInfo' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->newPagesInto' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->newContentInto' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->newPagesAfter' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->web_list_modTSconfig' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->allowedNewTables' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->deniedNewTables' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->web_list_modTSconfig_pid' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->allowedNewTables_pid' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->deniedNewTables_pid' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->code' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->R_URI' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->returnUrl' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->pagesOnly' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\NewRecordController->tRows' => [
        'restFiles' => [
            'Deprecation-84341-ProtectedMethodsAndPropertiesInNewRecordController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\EditController->doClose' => [
        'restFiles' => [
            'Deprecation-84327-DeprecatedPublicMethodsAndPropertiesInWizardEditController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\SimpleDataHandlerController->flags' => [
        'restFiles' => [
            'Deprecation-84374-ProtectedMethodsAndPropertiesInSimpleDataHandlerController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\SimpleDataHandlerController->mirror' => [
        'restFiles' => [
            'Deprecation-84374-ProtectedMethodsAndPropertiesInSimpleDataHandlerController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\SimpleDataHandlerController->cacheCmd' => [
        'restFiles' => [
            'Deprecation-84374-ProtectedMethodsAndPropertiesInSimpleDataHandlerController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\SimpleDataHandlerController->CB' => [
        'restFiles' => [
            'Deprecation-84374-ProtectedMethodsAndPropertiesInSimpleDataHandlerController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\TableController->inputStyle' => [
        'restFiles' => [
            'Deprecation-84338-ProtectedMethodsAndPropertiesInTableController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\TableController->xmlStorage' => [
        'restFiles' => [
            'Deprecation-84338-ProtectedMethodsAndPropertiesInTableController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\TableController->numNewRows' => [
        'restFiles' => [
            'Deprecation-84338-ProtectedMethodsAndPropertiesInTableController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\TableController->colsFieldsName' => [
        'restFiles' => [
            'Deprecation-84338-ProtectedMethodsAndPropertiesInTableController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\TableController->TABLECFG' => [
        'restFiles' => [
            'Deprecation-84338-ProtectedMethodsAndPropertiesInTableController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\TableController->tableParsing_quote' => [
        'restFiles' => [
            'Deprecation-84338-ProtectedMethodsAndPropertiesInTableController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\TableController->tableParsing_delimiter' => [
        'restFiles' => [
            'Deprecation-84338-ProtectedMethodsAndPropertiesInTableController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Recordlist\RecordList\DatabaseRecordList->newWizards' => [
        'restFiles' => [
            'Deprecation-84463-PageTsConfigOptionModweb_listnewWizardsDropped.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Authentication\BackendUserAuthentication->TSdataArray' => [
        'restFiles' => [
            'Deprecation-84984-ProtectedUserTSconfigPropertiesInBackendUserAuthentication.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Authentication\BackendUserAuthentication->userTS' => [
        'restFiles' => [
            'Deprecation-84984-ProtectedUserTSconfigPropertiesInBackendUserAuthentication.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Authentication\BackendUserAuthentication->userTSUpdated' => [
        'restFiles' => [
            'Deprecation-84984-ProtectedUserTSconfigPropertiesInBackendUserAuthentication.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Authentication\BackendUserAuthentication->userTS_text' => [
        'restFiles' => [
            'Deprecation-84984-ProtectedUserTSconfigPropertiesInBackendUserAuthentication.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Authentication\BackendUserAuthentication->userTS_dontGetCached' => [
        'restFiles' => [
            'Deprecation-84984-ProtectedUserTSconfigPropertiesInBackendUserAuthentication.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\View\PagePositionMap->getModConfigCache' => [
        'restFiles' => [
            'Deprecation-84984-ProtectedUserTSconfigPropertiesInBackendUserAuthentication.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\View\PagePositionMap->modConfigStr' => [
        'restFiles' => [
            'Deprecation-84984-ProtectedUserTSconfigPropertiesInBackendUserAuthentication.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Charset\CharsetConverter->noCharByteVal' => [
        'restFiles' => [
            'Deprecation-85122-FunctionalityInCharsetConverter.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Charset\CharsetConverter->parsedCharsets' => [
        'restFiles' => [
            'Deprecation-85122-FunctionalityInCharsetConverter.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Charset\CharsetConverter->toASCII' => [
        'restFiles' => [
            'Deprecation-85122-FunctionalityInCharsetConverter.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Charset\CharsetConverter->twoByteSets' => [
        'restFiles' => [
            'Deprecation-85122-FunctionalityInCharsetConverter.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Charset\CharsetConverter->eucBasedSets' => [
        'restFiles' => [
            'Deprecation-85122-FunctionalityInCharsetConverter.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Setup\Controller\SetupModuleController->OLD_BE_USER' => [
        'restFiles' => [
            'Deprecation-85196-ProtectSetupModuleController.rst'
        ],
    ],
    'TYPO3\CMS\Setup\Controller\SetupModuleController->MOD_MENU' => [
        'restFiles' => [
            'Deprecation-85196-ProtectSetupModuleController.rst'
        ],
    ],
    'TYPO3\CMS\Setup\Controller\SetupModuleController->MOD_SETTINGS' => [
        'restFiles' => [
            'Deprecation-85196-ProtectSetupModuleController.rst'
        ],
    ],
    'TYPO3\CMS\Setup\Controller\SetupModuleController->overrideConf' => [
        'restFiles' => [
            'Deprecation-85196-ProtectSetupModuleController.rst'
        ],
    ],
    'TYPO3\CMS\Setup\Controller\SetupModuleController->languageUpdate' => [
        'restFiles' => [
            'Deprecation-85196-ProtectSetupModuleController.rst'
        ],
    ],
    'TYPO3\CMS\Scheduler\Controller\SchedulerModuleController->CMD' => [
        'restFiles' => [
            'Deprecation-84387-DeprecatedMethodAndPropertyInSchedulerModuleController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst'
        ],
    ],
    'TYPO3\CMS\Backend\Template\DocumentTemplate->hasDocheader' => [
        'restFiles' => [
            'Deprecation-85735-MethodAndPropertyInDocumentTemplate.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->popView' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->modSharedTSconfig' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->colPosList' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->EDIT_CONTENT' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->CALC_PERMS' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->MCONF' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->MOD_MENU' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->current_sys_language' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\PageLayoutController->activeColPosList' => [
        'restFiles' => [
            'Deprecation-84375-ProtectedMethodsAndPropertiesInPageLayoutController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->menuNumber' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->entryLevel' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->spacerIDList' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->doktypeExcludeList' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->alwaysActivePIDList' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->imgNamePrefix' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->imgNameNotRandom' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->debug' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->GMENU_fixKey' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->MP_array' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->conf' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->mconf' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->sys_page' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->nextActive' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->menuArr' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->hash' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->result' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->rL_uidRegister' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->INPfixMD5' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->I' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->WMresult' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->WMfreezePrefix' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->WMmenuItems' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->WMsubmenuObjSuffixes' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->WMextraScript' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->WMcObj' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->alternativeMenuTempArray' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\AbstractMenuContentObject->nameAttribute' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\FrontendBackendUserAuthentication->adminPanel' => [
        'restFiles' => [
            'Deprecation-84641-DeprecatedAdminPanelRelatedMethods.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\FrontendBackendUserAuthentication->extAdminConfig' => [
        'restFiles' => [
            'Deprecation-84641-DeprecatedAdminPanelRelatedMethods.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\FrontendBackendUserAuthentication->extAdmEnabled' => [
        'restFiles' => [
            'Deprecation-84641-DeprecatedAdminPanelRelatedMethods.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\FrontendBackendUserAuthentication->frontendEdit' => [
        'restFiles' => [
            'Deprecation-86110-FrontendEditingController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->ADMCMD_preview_BEUSER_uid' => [
        'restFiles' => [
            'Deprecation-86047-TSFEPropertiesMethodsAndChangeVisibility.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->workspacePreview' => [
        'restFiles' => [
            'Deprecation-86047-TSFEPropertiesMethodsAndChangeVisibility.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->loginAllowedInBranch' => [
        'restFiles' => [
            'Deprecation-86047-TSFEPropertiesMethodsAndChangeVisibility.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->MP_defaults' => [
        'restFiles' => [
            'Deprecation-86047-TSFEPropertiesMethodsAndChangeVisibility.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->debug' => [
        'restFiles' => [
            'Deprecation-86047-TSFEPropertiesMethodsAndChangeVisibility.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->pageAccessFailureHistory' => [
        'restFiles' => [
            'Deprecation-86047-TSFEPropertiesMethodsAndChangeVisibility.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->loginAllowedInBranch_mode' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->cacheTimeOutDefault' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->cacheContentFlag' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->isClientCachable' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->no_cacheBeforePageGen' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->tempContent' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->pagesTSconfig' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->uniqueCounter' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->uniqueString' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->lang' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->cacheExpires' => [
        'restFiles' => [
            'Deprecation-86320-MarkInternalTSFEPropertiesAsProtected.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->blockElementList' => [
        'restFiles' => [
            'Deprecation-86440-InternalMethodsAndPropertiesWithinRteHtmlParser.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->recPid' => [
        'restFiles' => [
            'Deprecation-86440-InternalMethodsAndPropertiesWithinRteHtmlParser.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->elRef' => [
        'restFiles' => [
            'Deprecation-86440-InternalMethodsAndPropertiesWithinRteHtmlParser.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->tsConfig' => [
        'restFiles' => [
            'Deprecation-86440-InternalMethodsAndPropertiesWithinRteHtmlParser.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->procOptions' => [
        'restFiles' => [
            'Deprecation-86440-InternalMethodsAndPropertiesWithinRteHtmlParser.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->TS_transform_db_safecounter' => [
        'restFiles' => [
            'Deprecation-86440-InternalMethodsAndPropertiesWithinRteHtmlParser.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->getKeepTags_cache' => [
        'restFiles' => [
            'Deprecation-86440-InternalMethodsAndPropertiesWithinRteHtmlParser.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->allowedClasses' => [
        'restFiles' => [
            'Deprecation-86440-InternalMethodsAndPropertiesWithinRteHtmlParser.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Authentication\BackendUserAuthentication->checkWorkspaceCurrent_cache' => [
        'restFiles' => [
            'Deprecation-86441-VariousMethodsAndPropertiesInsideBackendUserAuthentication.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->raw' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->rawP' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->lastComment' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->commentSet' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->multiLineEnabled' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->multiLineObject' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->multiLineValue' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->inBrace' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->lastConditionTrue' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->syntaxHighLight' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->highLightData' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->highLightData_bracelevel' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->highLightStyles' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->highLightBlockStyles' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\Parser\TypoScriptParser->highLightBlockStyles_basecolor' => [
        'restFiles' => [
            'Deprecation-86461-MarkVariousTypoScriptParsingFunctionalityAsInternal.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Controller\ActionController->namespacesViewObjectNamePattern' => [
        'restFiles' => [
            'Breaking-87511-RemoveNamespacesViewObjectNamePatternProperty.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Controller\ActionController->viewFormatToObjectNameMap' => [
        'restFiles' => [
            'Breaking-87511-RemoveViewFormatToObjectNameMapProperty.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Web\Response->environmentService' => [
        'restFiles' => [
            'Deprecation-89468-DeprecateInjectionOfEnvironmentServiceInWebRequest.rst',
        ],
    ],
    'TYPO3\CMS\Core\Localization\LanguageService->LL_files_cache' => [
        'restFiles' => [
            'Deprecation-90964-LanguageServiceFunctionalityAndInternalProperties.rst',
        ],
    ],
    'TYPO3\CMS\Core\Localization\LanguageService->LL_labels_cache' => [
        'restFiles' => [
            'Deprecation-90964-LanguageServiceFunctionalityAndInternalProperties.rst',
        ],
    ],
];
